@@ -291,23 +291,51 @@ class RDSClient():
         query = f"SELECT * FROM neuralplatform_classdefinition WHERE project_id = {project_id};"
         return self.select_query(query)
 
+    def get_base_models(self,
+                        task_type: str):
+        """
+        """
+        assert task_type in ("CLS", "EXT")
+        query = f"SELECT * FROM neuralplatform_basemodel WHERE taskType = {task_type}"
+        return self.select_query(query)
+
     def insert_model(self,
                      version_id: int,
-                     model_name: str,
-                     hyperparams: str,
-                     results_file_uri: str) -> int:
+                     base_model_id: int,
+                     hyperparams: dict) -> int:
         """
         """
-        query = f"INSERT INTO neuralplatform_model(name, hyperparams, resultsFileUri, version_id) VALUES('{model_name}', '{hyperparams}', '{results_file_uri}', {version_id});"
+        query = f"INSERT INTO neuralplatform_model(baseModel_id, version_id, hyperparams) VALUES('{base_model_id}', {version_id}, '{json.dumps(hyperparams)}');"
         return self.insert_query(query)
     
+    def update_model_results_uri(self, 
+                                 model_id: int,
+                                 results_file_uri: str):
+        """
+        """
+        query = f"UPDATE neuralplatform_model SET resultsFileUri = {results_file_uri} WHERE id = {model_id};"
+    
+    def update_model_uri(self, 
+                         model_id: int,
+                         model_uri: str):
+        """
+        """
+        query = f"UPDATE neuralplatform_model SET modelUri = {model_uri} WHERE id = {model_id};"
+    
     def get_version_model(self,
-                  version_id: int) -> dict:
+                          version_id: int) -> dict:
         """
         """
-        query = f"SELECT * FROM neuralplatform_model WHERE version_id = {version_id};"
+        query = f"SELECT * FROM neuralplatform_model WHERE id = (SELECT bestModel_id FROM neuralplatform_version WHERE version_id = {version_id});"
         return self.select_query(query, fetchone=True)
     
+    def get_model_params(self,
+                         model_id: int) -> dict:
+        """
+        """
+        query = f"SELECT hyperparams FROM neuralplatform_model WHERE id={model_id};"
+        return json.loads(self.select_query(query, fetchone=True))
+    
     def insert_class_performance(self,
                                  model_id: int,
                                  class_id: int,
